<?xml version="1.0"?>
<xsl:stylesheet xmlns="http://www.mpiwg-berlin.mpg.de/ns/echo/1.0/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                exclude-result-prefixes="xs"
                xmlns:de="http://www.mpiwg-berlin.mpg.de/ns/de/1.0/"
                xmlns:dcterms="http://purl.org/dc/terms"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:echo="http://www.mpiwg-berlin.mpg.de/ns/echo/1.0/"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:mml="http://www.w3.org/1998/Math/MathML"
                xmlns:xlink="http://www.w3.org/1999/xlink"
                xmlns:xml="http://www.w3.org/XML/1998/namespace"
                version="2.0">
  <!-- was noch zu machen ist
       - Zeilenumbrüche fehlen!!! Das ist auch nicht zu schaffen.
       - figures in p haben nur anchor
       - s und div später durch Workflowskripte
  -->
  <!-- <xsl:output method="xml" indent="yes" encoding="UTF-8"/> -->
  <xsl:output method="xml" encoding="UTF-8"/>
  <!-- output the whole document with doing nearly nothing -->
  <xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>

  <!-- figure not in p -->
  <xsl:template match="*:text/*:figure">
    <xsl:variable name="filename" select="."/>
    <xsl:value-of select="'&#xA;'"/>
    <xsl:element name="figure">
      <xsl:value-of select="'&#xA;'"/>
      <xsl:element name="image">
        <xsl:attribute name="file">
          <xsl:value-of select="$filename"/>
        </xsl:attribute>
        <xsl:attribute name="xlink:href">
          <xsl:text>http://echo.mpiwg-berlin.mpg.de/zogilib?fn=/permanent/library/QFWN4Q67/figures/</xsl:text>
          <xsl:value-of select="$filename"/>
        </xsl:attribute>
      </xsl:element>
      <xsl:value-of select="'&#xA;'"/>
    </xsl:element>
    <xsl:value-of select="'&#xA;'"/>
  </xsl:template>
  <!-- figure in p -->
  <!--                 <anchor type="figure"
       xlink:label="fig-0397-01a" xlink:href="fig-0397-01"/> -->
  <xsl:template match="*:p/*:figure">
    <xsl:variable name="filename" select="."/>
    <xsl:element name="anchor">
      <xsl:attribute name="type">figure</xsl:attribute>
      <xsl:attribute name="xlink:label">
        <xsl:value-of select="$filename"/>
        <xsl:text>a</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="xlink:href">
        <xsl:value-of select="$filename"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>
  
  <!-- math -->
  <xsl:template match="*:math">
    <xsl:choose>
      <xsl:when test="*:content/*:power">
        <xsl:element name="mml:math">
          <xsl:element name="mml:msup">
            <xsl:element name="mml:mi">
              <!-- select only the text of this node without its children -->
              <xsl:value-of select="*:content/text()"/>
            </xsl:element>
            <xsl:element name="mml:mn">
              <xsl:apply-templates select="*:content/*:power/node()"/>
            </xsl:element>
          </xsl:element>
        </xsl:element>
        <!-- <xsl:comment>power</xsl:comment> -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:element name="mml:math">
          <xsl:element name="mml:mi">
            <xsl:apply-templates select="*:content/node()"/>
          </xsl:element>
        </xsl:element>
        <!-- <xsl:comment>einfaches mathml </xsl:comment> -->
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <!-- cong, dag, nl and lacs -->
  <xsl:template match="*:cong">
    <xsl:comment>begin cong</xsl:comment>
    <xsl:apply-templates select="node()"/>
    <xsl:comment>end cong</xsl:comment>
  </xsl:template>
  <xsl:template match="*:dag">
    <xsl:comment>begin dag</xsl:comment>
    <xsl:apply-templates select="node()"/>
    <xsl:comment>end dag</xsl:comment>
  </xsl:template>
  <xsl:template match="*:lacs">
    <xsl:comment>milestone lacs</xsl:comment>
  </xsl:template>
  <xsl:template match="*:nl">
    <xsl:comment>milestone nl</xsl:comment>
  </xsl:template>

  <!-- table -->
  <xsl:template match="*:tabula">
    <xsl:element name="xhtml:table">
      <xsl:apply-templates select="node()"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="*:tr">
    <xsl:element name="xhtml:tr">
      <xsl:apply-templates select="node()"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="*:td">
    <xsl:element name="xhtml:td">
      <xsl:apply-templates select="node()"/>
    </xsl:element>
  </xsl:template>

  <!-- italics -->
  <xsl:template match="*:italics">
    <xsl:element name="emph">
      <xsl:attribute name="style">it</xsl:attribute>
      <xsl:apply-templates select="node()"/>
    </xsl:element>
  </xsl:template>

  <!-- underline -->
  <xsl:template match="*:underline">
    <xsl:element name="emph">
      <xsl:attribute name="style">ul</xsl:attribute>
      <xsl:apply-templates select="node()"/>
    </xsl:element>
  </xsl:template>

  <!-- enunciatio -->
  <xsl:template match="*:enunciatio">
    <xsl:element name="head">
      <xsl:attribute name="xml:space">preserve</xsl:attribute>
      <xsl:apply-templates select="*:content/node()"/>
    </xsl:element>
  </xsl:template>

  <!-- capitolo -->
  <xsl:template match="*:capitolo">
    <xsl:element name="head">
      <xsl:attribute name="xml:space">preserve</xsl:attribute>
      <xsl:apply-templates select="node()"/>
    </xsl:element>
  </xsl:template>

  <!-- citmarg - convert them to marginal notes in the left margin
       (most of them are in the left margin) and let the move floats
       script do the rest-->
  <xsl:template match="*:citmarg">
    <xsl:value-of select="'&#xA;'"/>
    <xsl:element name="mgl">
      <xsl:value-of select="'&#xA;'"/>
      <!-- <xsl:value-of select="."/> -->
      <xsl:apply-templates select="node()"/>
      <xsl:value-of select="'&#xA;'"/>
    </xsl:element>
    <xsl:value-of select="'&#xA;'"/>
  </xsl:template>

  <xsl:template match="*:citmargsign">
    <xsl:value-of select="'&#xA;'"/>
    <xsl:element name="mgl">
      <xsl:value-of select="'&#xA;'"/>
      <!-- <xsl:value-of select="."/> -->
      <xsl:apply-templates select="node()"/>
      <xsl:comment>citmargsign</xsl:comment>
      <xsl:value-of select="'&#xA;'"/>
    </xsl:element>
    <xsl:value-of select="'&#xA;'"/>
  </xsl:template>


  <!-- variant -->
  <xsl:template match="*:variant">
    <xsl:choose>
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='SupraLineam'">
        <xsl:element name="emph">
          <xsl:attribute name="style">super</xsl:attribute>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/> <xsl:comment>variant supralineam</xsl:comment>
        </xsl:element>
      </xsl:when>
      <!-- using bold face for postcorrectionem -->
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='PostCorrectionem'">
        <xsl:element name="emph">
          <xsl:attribute name="style">bf</xsl:attribute>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
          <xsl:comment>variant postcorrectionem</xsl:comment>
        </xsl:element>
      </xsl:when>
      <!-- delevit -->
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem[3]/*:ontologyreference/@id='Delevit'">
        <!-- second decision, post or ante -->
        <xsl:choose>
          <!-- ante -->
          <xsl:when test="*:variantitem/*:description/*:descriptionitem[1]/*:ontologyreference/node()='ante'">
            <xsl:comment>begin variant delevit ante</xsl:comment>
            <xsl:element name="emph">
              <xsl:attribute name="style">st</xsl:attribute>
              <xsl:apply-templates select="*:variantitem/*:description/*:descriptionitem[3]/*:ontologyreference/node()"/>
            </xsl:element>
            <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
            <xsl:comment>end variant delevit ante</xsl:comment>
          </xsl:when>
          <!-- post -->
          <xsl:when test="*:variantitem/*:description/*:descriptionitem[1]/*:ontologyreference/node()='post'">
            <xsl:comment>begin variant delevit post</xsl:comment>
            <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
            <xsl:element name="emph">
              <xsl:attribute name="style">st</xsl:attribute>
              <xsl:apply-templates select="*:variantitem/*:description/*:descriptionitem[3]/*:ontologyreference/node()"/>
              <xsl:comment>end variant delevit post</xsl:comment>
            </xsl:element>
          </xsl:when>
        </xsl:choose>
      </xsl:when>
      <!-- Notlösung hier, die meisten sind "diverso atramento".
           Erstmal auf italics gesetzt. -->
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='Descriptio'">
        <xsl:element name="emph">
          <xsl:attribute name="style">it</xsl:attribute>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
          <xsl:comment>variant descriptio: <xsl:value-of select="*:variantitem/*:description/*:descriptionitem/*:ontologyreference"/> </xsl:comment>
        </xsl:element>
      </xsl:when>
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='SignoPositoInMargine'">
        <xsl:value-of select="'&#xA;'"/>
        <xsl:element name="mgl">
          <xsl:value-of select="'&#xA;'"/>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
          <xsl:comment>variant signopositoinmargine</xsl:comment>
          <xsl:value-of select="'&#xA;'"/>
        </xsl:element>
        <xsl:value-of select="'&#xA;'"/>
      </xsl:when>
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='EDdiverso atramento'">
        <xsl:element name="emph">
          <xsl:attribute name="style">it</xsl:attribute>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
          <xsl:comment>variant EDdiverso atramento</xsl:comment>
        </xsl:element>
      </xsl:when>
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='InMargine'">
        <xsl:value-of select="'&#xA;'"/>
        <xsl:element name="mgl">
          <xsl:value-of select="'&#xA;'"/>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
          <xsl:comment>variant inmargine</xsl:comment>
          <xsl:value-of select="'&#xA;'"/>
        </xsl:element>
        <xsl:value-of select="'&#xA;'"/>
      </xsl:when>
      <xsl:when
          test="*:variantitem/*:description/*:bis">
        <xsl:element name="sic">
          <xsl:attribute name="comment">bis</xsl:attribute>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
          <xsl:comment>variant bis</xsl:comment>
        </xsl:element>
      </xsl:when>
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='EDspatium rel.'">
        <xsl:value-of select="'&#xA;'"/>
        <xsl:element name="mgl">
          <xsl:value-of select="'&#xA;'"/>
          <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/>
          <xsl:comment>variant edspatium rel</xsl:comment>
          <xsl:value-of select="'&#xA;'"/>
        </xsl:element>
        <xsl:value-of select="'&#xA;'"/>
      </xsl:when>
      <xsl:when
          test="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id='CorrexitEx'">
        <xsl:element name="reg">
          <!-- OBS reg darf keine Tags drin haben! -->
          <xsl:attribute name="norm">
            <xsl:apply-templates select="*:variantitem/*:description/*:descriptionitem/*:reading/*:content/node()"/>
          </xsl:attribute>
          <!-- type: a whole bunch of reg types: "lig" "abbr" "simple" "context" "wordlist" "wordlist/context" "unresolved" "punctuation" "typo" "conjecture" "arguable" "unknown" -->
          <xsl:attribute name="type">context</xsl:attribute>
          <!-- no tags in reg -->
          <xsl:value-of select="*:variantitem/*:reading/*:content/node()"/>
          <!-- <xsl:apply-templates select="*:variantitem/*:reading/*:content/node()"/> -->
          <xsl:comment>variant correxitex <!-- <xsl:value-of select="count(*:variantitem)"/> --> </xsl:comment>
        </xsl:element>
      </xsl:when>
      <xsl:when test="count(*:variantitem)=2">
        <xsl:element name="reg">
          <xsl:attribute name="norm">
            <xsl:apply-templates select="*:variantitem[1]/*:reading/*:content/node()"/>
          </xsl:attribute>
          <xsl:attribute name="type">context</xsl:attribute>
          <!-- no tags in reg -->
          <xsl:value-of select="*:variantitem[2]/*:reading/*:content/node()"/>
          <!-- <xsl:apply-templates select="*:variantitem[2]/*:reading/*:content/node()"/> -->
          <xsl:comment>variant 2 variants</xsl:comment>
        </xsl:element>
      </xsl:when>
      <xsl:otherwise>
        <xsl:comment>
          <xsl:text>unresolved variant </xsl:text>
          <xsl:value-of select="*:variantitem/*:description/*:descriptionitem/*:ontologyreference/@id"/>
        </xsl:comment>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>
